## SPEAC-analysis python library ##
* [David Cope's](http://artsites.ucsc.edu/faculty/cope/) SPEAC-analysis rewritten from Common Lisp to Python
* David Cope's book: [Computer Models of Musical Creativity](https://books.google.de/books?id=rnEJAQAAMAAJ). Cambridge, MA: MIT Press. 2006.
* Original code source: https://github.com/HeinrichApfelmus/david-cope-cmmc 
* See the source for this project here: 'https://github.com/GolzitskyNikolay/SPEAC-analysis/'
